@@ -1,32 +1,27 @@
-# source("~/Desktop/Research/BFF/R/FINAL_SUPPORT_hypergeometric.R")
-# source("~/Desktop/Research/BFF/R/FINAL_FUNCTIONS_tau2.R")
-# source("~/Desktop/Research/BFF/R/FINAL_FUNCTIONS_plotting.R")
-
-
 ###########################################################################################################
 ###########functions to set tau2 - user does not interact with these ######################################
 ###########################################################################################################
-get_one_sample_tau2 = function(n, w, r = 1)
+get_one_sample_tau2 = function(n, w, r)
 {
   to_return = n * w ^ 2 / (2 * r)
   return(to_return)
 }
 
-get_two_sample_tau2 = function(n1, n2, w, r = 1)
+get_two_sample_tau2 = function(n1, n2, w, r)
 {
-  to_return = n1 * n2 * w ^ 2 / (2 * r * (n1 + n2))
+  to_return = n1 * n2 * w ^ 2 / (2 * r *(n1 + n2))
   return(to_return)
 }
 
-get_count_tau2 = function(n, w, k, r = 1)
+get_count_tau2 = function(n, w, k, r)
 {
   top = n * w ^ 2 * k
-  bottom = 2 * (k / 2 + r - 1)
+  bottom =2 * (k / 2 + r - 1)
   to_return = top / bottom
   return(to_return)
 }
 
-get_LRT_tau2 = function(n, w, k, r = 1)
+get_LRT_tau2 = function(n, w, k, r)
 {
   top = n * k * w ^ 2
   bottom = 2 * (k / 2 + r - 1)
@@ -34,14 +29,30 @@ get_LRT_tau2 = function(n, w, k, r = 1)
   return(to_return)
 }
 
-get_linear_tau2 = function(n, w, k, r = 1)
+get_linear_tau2 = function(n, w, k, r)
 {
-  top = 2 * k * w ^ 2
+  top = n * k * w ^ 2
   bottom = 4 * (k / 2 + r - 1)
   to_return = top / bottom
   return(to_return)
 }
 
+# not currently using
+get_corr_tau2 = function(n, w)
+{
+  top = (n-2) * w^2
+  bottom = 2
+  to_return = top / bottom
+  return(to_return)
+}
+
+get_regression_tau2 = function(n, k, w, r)
+{
+  top = (n-k-1)*w^2
+  bottom = (2* r)
+  to_return = top / bottom
+  return(to_return)
+}
 
 ################## for fractional cases
 # get_wbar = function(w, k)
